@@ -1,25 +1,27 @@
 package Time::Simple;
 
 use 5.008003;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $FATALS  = 1;
 
 =head1 NAME
 
-Time::Simple - a very light time object
+Time::Simple - A simple, light-weight ISO 8601 time object.
 
 =head1 SYNOPSIS
 
 	use Time::Simple;
 	my $time   = Time::Simple->new('23:24:59');
-	my $hour   = $time->hour;
-	my $minute = $time->minute;
-	my $second = $time->second;
+	my $hour   = $time->hours;
+	my $minute = $time->minutes;
+	my $second = $time->seconds;
+
 	my $time2  = Time::Simple->new($hour, $minute, $second);
 
 	my $now = Time::Simple->new;
 	my $nexthour = $now + 60;
 	print "An hour from now is $nexthour.\n";
+
 	if ($nexthour->hour > 23) {
 		print "It'll be tomorrow within the next hour!\n";
 	}
@@ -29,15 +31,25 @@ Time::Simple - a very light time object
 	# ...and this:
 	($time <=> [23, 24, 25])
 
+	$time++; # Add a minute
+	$time--; # Subtract a minute
+
+	my $now  = Time::Simple->new;
+	# A minute from now:
+	my $then = Time::Simple->new( $now + 60 );
+	# Or:
+	my $soon = Time::Simple->new( '00:01:00' );
+
 =head1 DESCRIPTION
 
-This object represents a class for simple and light time objects,
-just as C<Date::Simple> represents a class for simple objects.
+A simple, light-weight time object.
 
-Attempting to create an invalid time with this module  will return C<undef> rather than an object.
+This version should be considered alpha: stable, but not yet thourghly tested.
 
 =head1 FATAL ERRORS
 
+Attempting to create an invalid time with this module will return C<undef> rather than an object.
+
 Some operations can produce fatal errors: these can be replaced by warnings and the
 return of C<undef> by switching the value of C<$FATALS>:
 
@@ -59,8 +71,11 @@ use Carp;
 use POSIX qw(strftime mktime);
 
 use overload
+	'='	  => '_copy',
     '+='  => '_increment',
+	'++'  => '_increment_mod',
     '-='  => '_decrement',
+    '--'  => '_decrement_mod',
     '+'   => '_add',
     '-'   => '_subtract',
     '<=>' => '_compare',
@@ -69,12 +84,19 @@ use overload
 
 =head2 CONSTRUCTOR (new)
 
-    my $time = Time::Simple->new('21:10:00');
-    my $othertime = Time::Simple->new(11, 10, 9);
+    $_ = Time::Simple->new('21:10:09');
+    $_ = Time::Simple->new( 11,10, 9 );
+    $_ = Time::Simple->new( time() );
 
 The constructor C<new> returns a C<Time::Simple> object if the supplied
 values specify a valid time, otherwise returns C<undef>.
 
+Valid times are either as supplied by the L<time|perlfunc/time>, or in ISO 8601
+format. In the latter case, the values may be supplied as a colon-delimited scalar,
+as a list, or as an anonymous array.
+
+If nothing is supplied to the constructor, the current local time will be used.
+
 =cut
 
 sub new {
@@ -84,15 +106,24 @@ sub new {
         if(ref $hms[0] eq 'ARRAY') {
             @hms = join':',@{$hms[0]};
 		}
+		# From "time"
+		elsif ($hms[0] =~ /^[^:]{10}$/g){
+			Carp::confess;
+			my $hms = $hms[0];
+			my $h = (localtime $hms)[2];
+			my $m = (localtime $hms)[1];
+			my $s = (localtime $hms)[0];
+			@hms = ($h, $m, $s);
+		}
 		@hms = $hms[0] =~ /^(\d{1,2})(:\d{1,2})?(:\d{1,2})?$/;
 		$hms[1] ||= '00';
 		$hms[2] ||= '00';
 		s/^:// foreach @hms[1..2];
 		if (not defined $hms[0]){
 			if ($FATALS){
-				croak"'$_[0]' is not a valid ISO formated time" ;
+				croak"'$_[0]' is not a valid ISO 8601 formated time" ;
 			} else {
-				Carp::cluck("'$_[0]' is not a valid ISO formated time") if $^W;
+				Carp::cluck("'$_[0]' is not a valid ISO 8601 formated time") if $^W;
 				return undef;
 			}
         }
@@ -115,14 +146,6 @@ sub new {
 sub next { return $_[0] + 1 }
 sub prev { return $_[0] - 1 }
 
-# return a copy of self
-sub _copy {
-    my $self = shift;
-    my $copy = \$$self;
-    bless $copy, ref $self;
-    return $copy;
-}
-
 sub _mkdatehms ($$$) {
     my ($h, $m, $s) = @_;
 	# mktime(sec, min, hour, mday, mon, year, wday = 0, yday = 0, isdst = 0)
@@ -134,15 +157,22 @@ sub _mkdatehms ($$$) {
     return $d;
 }
 
-sub hour   { return (localtime ${$_[0]})[2] }
-sub minute { return (localtime ${$_[0]})[1] }
-sub second { return (localtime ${$_[0]})[0] }
+sub hour    { return (localtime ${$_[0]})[2] }
+sub hours   { return (localtime ${$_[0]})[2] }
+
+sub minute  { return (localtime ${$_[0]})[1] }
+sub minutes { return (localtime ${$_[0]})[1] }
+
+sub second  { return (localtime ${$_[0]})[0] }
+sub seconds { return (localtime ${$_[0]})[0] }
 
 sub format {
     my $self = shift;
     my $format = shift || '%H:%M:%S';
 	# strftime(fmt, sec, min, hour, mday, mon, year, wday = -1, yday = -1, isdst = -1)
-    return strftime $format, localtime $$self;
+    my $return = eval {strftime $format, localtime $$self;};
+    Carp::confess "You supplied $$self: ".$@ if $@;
+    return $return;
 }
 
 sub validate ($$$) {
@@ -163,36 +193,69 @@ sub validate ($$$) {
 #------------------------------------------------------------------------------
 sub _stringify { $_[0]->format }
 
+sub _copy {
+    my $self = shift;
+	my $v = $$self;
+    my $copy = \$v;
+    bless $copy, ref $self;
+    return $copy;
+}
+
 sub _increment {
     my ($self, $n) = @_;
-    $$self += $n;
+    if (UNIVERSAL::isa($n, 'Time::Simple')) {
+		$n = $$n;
+	}
+	my $copy = $self->_copy;
+    $$copy+= $n;
+    return $copy;
+}
+
+sub _increment_mod {
+    my ($self, $n) = @_;
+    $n = $$n if UNIVERSAL::isa($n, 'Time::Simple');
+	$$self ++;
     return $self;
 }
 
 sub _decrement {
     my ($self, $n, $reverse) = @_;
-    $$self -= $n;
-    return $self;
+    $n = $$n if UNIVERSAL::isa($n, 'Time::Simple');
+	my $copy = $self->_copy;
+    $$copy -= $n;
+    return $copy;
+}
+
+sub _decrement_mod {
+    my ($self, $n, $reverse) = @_;
+    $n = $$n if UNIVERSAL::isa($n, 'Time::Simple');
+	$$self --;
+	return $self;
 }
 
 sub _add {
-    my ($self, $n) = @_;
-    my $copy = $self->_copy;
-    $copy += $n;
-    return $copy;
+    my ($self, $n, $reverse) = @_;
+    if (UNIVERSAL::isa($n, 'Time::Simple')) {
+		my $s = ($n->hour * 60 * 60)
+			+ ($n->minute * 60)
+			+ $n->seconds;
+		$n = $s;
+    }
+	my $copy = $self->_copy;
+	$$copy += $n;
+	return $copy;
 }
 
 sub _subtract {
     my ($self, $n, $reverse) = @_;
     if (UNIVERSAL::isa($n, 'Time::Simple')) {
         my $diff = $$self - $$n;
-        $diff /= 86400;
+        # $diff /= 86400;
         # $reverse should probably always be false here, but...
         return $reverse ? -$diff : $diff;
     } else {
-        # we don't know how to subtract a time from a non-time
         my $copy = $self->_copy;
-        $copy -= $n;
+        $$copy -= $n;
         return $copy;
     }
 }
@@ -250,32 +313,33 @@ If you don't pass a parameter, an ISO 8601 formatted time is returned.
     $date->format("%H hours, %M minutes, and %S seconds");
     $date->format("%H-%M-%S");
 
-The formatting parameter is as you would pass to C<strftime(3)>: see
+The formatting parameter is as you would pass to C<strftime(3)>:
 L<POSIX/strftime>.
 
 =head1 OPERATORS
 
-Some operators can be used with Time::Simple objects:
+Some operators can be used with C<Time::Simple> objects:
 
 =over 4
 
-=item *
+=item += -=
 
-You can increment or decrement a time by a number of days using the
+You can increment or decrement a time by a number of seconds using the
 C<+=> and C<-=> operators
 
-=item *
+=item + -
 
 You can construct new times offset by a number of seconds using the
 C<+> and C<-> operators.
 
-=item *
+=item -
 
 You can subtract two times (C<$t1 - $t2>) to find the number of seconds between them.
 
-=item *
+=item comparison
 
-You can compare two times using the arithmetic and/or string comparison operators.
+You can compare two times using the arithmetic and/or string comparison operators:
+C<lt le ge gt E<lt> E<lt>= E<gt>= E<gt>>.
 
 =item *
 
@@ -293,11 +357,15 @@ if you supplied a scalar string: C<[11,10,09]>.
 
 =head1 TODO
 
-Suggestions welcome.
+Suggestions welcome. How should operators not mentioend behave? Can one C<verbar> times?
 
 =head1 SEE ALSO
 
-L<Date::Simple>, L<Time::HiRes>, L<perlop/localtime>, L<perlop/time>.
+L<Time::HiRes>, L<Date::Time>,
+L<Date::Simple>,
+L<perlfunc/localtime>,
+L<perlfunc/time>.
+L<POSIX/strftime>, L<POSIX/mktime>.
 
 =head1 CREDITS
 
@@ -305,6 +373,8 @@ This module is a rewrite of Marty Pauley's excellent and very useful C<Date::Sim
 object. If you're reading, Marty: many thanks. For support, though, please contact
 Lee Goddard (lgoddard -at- cpan -dot- org) or use rt.cpan.org.
 
+Thanks to Zsolt for testing.
+
 =head1 AUTHOR
 
 Lee Goddard (lgoddard -at- cpan -dot- org) after Marty Pauley.
